diff browser_side/richtext.py @ 401:ea03f898067f

browser_side: LightTextEditor renamed to HTMLTextEditor, new class LightTextEditor based on TextArea
author souliane <souliane@mailoo.org>
date Thu, 13 Mar 2014 13:15:48 +0100
parents 487dd238ab88
children c393e7dc9ae6
line wrap: on
line diff
--- a/browser_side/richtext.py	Tue Mar 11 13:53:19 2014 +0100
+++ b/browser_side/richtext.py	Thu Mar 13 13:15:48 2014 +0100
@@ -31,7 +31,7 @@
 
 from constants import Const
 from dialog import ConfirmDialog, InfoDialog
-from base_panels import TitlePanel, BaseTextEditor, LightTextEditor
+from base_panels import TitlePanel, BaseTextEditor, HTMLTextEditor
 from list_manager import ListManager
 from html_tools import html_sanitize
 import panels
@@ -107,7 +107,7 @@
         if hasattr(self, 'toolbar'):
             self.toolbar.setVisible(False)
         if not hasattr(self, 'display'):
-            self.display = LightTextEditor(enhance_display=False)  # for display mode
+            self.display = HTMLTextEditor(enhance_display=False)  # for display mode
             for listener in self.edit_listeners:
                 self.display.addEditListener(listener)
         if not self.read_only and not hasattr(self, 'textarea'):
@@ -316,7 +316,7 @@
             self.display.edit(False)
 
     def setDisplayContent(self):
         """Set the content of the LightTextEditor which is used for display/wysiwyg"""
         content = self._original_content
         text = content['text']
         if 'title' in content and content['title']:
@@ -316,7 +316,7 @@
 
     def setDisplayContent(self):
-        """Set the content of the LightTextEditor which is used for display/wysiwyg"""
+        """Set the content of the HTMLTextEditor which is used for display/wysiwyg"""
         content = self._original_content
         text = content['text']